@@ -1,5 +1,5 @@
 /*
-Copyright 2019 The Knative Authors.
+Copyright 2019 The Knative Authors
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -27,6 +27,7 @@ import (
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
+	"k8s.io/apimachinery/pkg/util/clock"
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	. "knative.dev/pkg/logging/testing"
@@ -77,7 +78,7 @@ func TestMetricCollectorCRUD(t *testing.T) {
 		coll := NewMetricCollector(failingFactory, logger)
 		got := coll.CreateOrUpdate(&defaultMetric)
 
-		if got != want {
+		if !errors.Is(got, want) {
 			t.Errorf("Create() = %v, want %v", got, want)
 		}
 	})
@@ -91,7 +92,7 @@ func TestMetricCollectorCRUD(t *testing.T) {
 
 		got := coll.collections[key].metric
 		if !cmp.Equal(&defaultMetric, got) {
-			t.Errorf("Get() didn't return the same metric: %v", cmp.Diff(&defaultMetric, got))
+			t.Error("Get() didn't return the same metric:", cmp.Diff(&defaultMetric, got))
 		}
 
 		defaultMetric.Spec.ScrapeTarget = "new-target"
@@ -102,7 +103,7 @@ func TestMetricCollectorCRUD(t *testing.T) {
 
 		got = coll.collections[key].metric
 		if !cmp.Equal(&defaultMetric, got) {
-			t.Errorf("Update() didn't return the same metric: %v", cmp.Diff(&defaultMetric, got))
+			t.Error("Update() didn't return the same metric:", cmp.Diff(&defaultMetric, got))
 		}
 
 		newURL := (coll.collections[key]).scraper.(*testScraper).url
@@ -110,12 +111,86 @@ func TestMetricCollectorCRUD(t *testing.T) {
 			t.Errorf("Updated scraper URL = %s, want: %s, diff: %s", got, want, cmp.Diff(got, want))
 		}
 
-		if err := coll.Delete(defaultNamespace, defaultName); err != nil {
-			t.Errorf("Delete() = %v, want no error", err)
-		}
+		coll.Delete(defaultNamespace, defaultName)
 	})
 }
 
+func TestMetricCollectorScraperMovingTime(t *testing.T) {
+	logger := TestLogger(t)
+
+	mtp := &fake.ManualTickProvider{
+		Channel: make(chan time.Time),
+	}
+	now := time.Now()
+	fc := fake.Clock{
+		FakeClock: clock.NewFakeClock(now),
+		TP:        mtp,
+	}
+	metricKey := types.NamespacedName{Namespace: defaultNamespace, Name: defaultName}
+	const (
+		reportConcurrency = 10
+		reportRPS         = 20
+		wantConcurrency   = 7 * 10 / 2
+		wantRPS           = 7 * 20 / 2
+		wantPConcurrency  = 7 * 10 / 2
+		wantPRPS          = 7 * 20 / 2
+	)
+	stat := Stat{
+		PodName:                   "testPod",
+		AverageConcurrentRequests: reportConcurrency,
+		RequestCount:              reportRPS,
+	}
+	scraper := &testScraper{
+		s: func() (Stat, error) {
+			return stat, nil
+		},
+	}
+	factory := scraperFactory(scraper, nil)
+
+	coll := NewMetricCollector(factory, logger)
+	coll.clock = fc
+	coll.CreateOrUpdate(&defaultMetric)
+
+	// Tick three times.  Time doesn't matter since we use the time on the Stat.
+	for i := 0; i < 3; i++ {
+		mtp.Channel <- now
+	}
+	now = now.Add(time.Second)
+	fc.SetTime(now)
+	for i := 0; i < 4; i++ {
+		mtp.Channel <- now
+	}
+	var gotRPS, gotConcurrency, panicRPS, panicConcurrency float64
+	// Poll to see that the async loop completed.
+	wait.PollImmediate(10*time.Millisecond, 2*time.Second, func() (bool, error) {
+		gotConcurrency, panicConcurrency, _ = coll.StableAndPanicConcurrency(metricKey, now)
+		gotRPS, panicRPS, _ = coll.StableAndPanicRPS(metricKey, now)
+		return gotConcurrency == wantConcurrency &&
+			panicConcurrency == wantPConcurrency &&
+			gotRPS == wantRPS &&
+			panicRPS == wantPRPS, nil
+	})
+
+	if _, _, err := coll.StableAndPanicConcurrency(metricKey, now); err != nil {
+		t.Error("StableAndPanicConcurrency() =", err)
+	}
+	if _, _, err := coll.StableAndPanicRPS(metricKey, now); err != nil {
+		t.Error("StableAndPanicRPS() =", err)
+	}
+	if panicConcurrency != wantPConcurrency {
+		t.Errorf("PanicConcurrency() = %v, want %v", panicConcurrency, wantPConcurrency)
+	}
+	if panicRPS != wantPRPS {
+		t.Errorf("PanicRPS() = %v, want %v", panicRPS, wantPRPS)
+	}
+	if gotConcurrency != wantConcurrency {
+		t.Errorf("StableConcurrency() = %v, want %v", gotConcurrency, wantConcurrency)
+	}
+	if gotRPS != wantRPS {
+		t.Errorf("StableRPS() = %v, want %v", gotRPS, wantRPS)
+	}
+}
+
 func TestMetricCollectorScraper(t *testing.T) {
 	logger := TestLogger(t)
 
@@ -123,6 +198,10 @@ func TestMetricCollectorScraper(t *testing.T) {
 		Channel: make(chan time.Time),
 	}
 	now := time.Now()
+	fc := fake.Clock{
+		FakeClock: clock.NewFakeClock(now),
+		TP:        mtp,
+	}
 	metricKey := types.NamespacedName{Namespace: defaultNamespace, Name: defaultName}
 	const (
 		reportConcurrency = 10
@@ -145,16 +224,16 @@ func TestMetricCollectorScraper(t *testing.T) {
 	factory := scraperFactory(scraper, nil)
 
 	coll := NewMetricCollector(factory, logger)
-	coll.tickProvider = mtp.NewTicker // custom ticker.
+	coll.clock = fc
 	coll.CreateOrUpdate(&defaultMetric)
 
 	// Tick three times.  Time doesn't matter since we use the time on the Stat.
-	mtp.Channel <- now
-	mtp.Channel <- now
-	mtp.Channel <- now
+	for i := 0; i < 3; i++ {
+		mtp.Channel <- now
+	}
 	var gotRPS, gotConcurrency, panicRPS, panicConcurrency float64
 	// Poll to see that the async loop completed.
-	wait.PollImmediate(10*time.Millisecond, 100*time.Millisecond, func() (bool, error) {
+	wait.PollImmediate(10*time.Millisecond, 2*time.Second, func() (bool, error) {
 		gotConcurrency, panicConcurrency, _ = coll.StableAndPanicConcurrency(metricKey, now)
 		gotRPS, panicRPS, _ = coll.StableAndPanicRPS(metricKey, now)
 		return gotConcurrency == wantConcurrency &&
@@ -163,10 +242,11 @@ func TestMetricCollectorScraper(t *testing.T) {
 			panicRPS == wantPRPS, nil
 	})
 
-	gotConcurrency, panicConcurrency, _ = coll.StableAndPanicConcurrency(metricKey, now)
-	gotRPS, panicRPS, err := coll.StableAndPanicRPS(metricKey, now)
-	if err != nil {
-		t.Errorf("StableAndPanicRPS = %v", err)
+	if _, _, err := coll.StableAndPanicConcurrency(metricKey, now); err != nil {
+		t.Error("StableAndPanicConcurrency() =", err)
+	}
+	if _, _, err := coll.StableAndPanicRPS(metricKey, now); err != nil {
+		t.Error("StableAndPanicRPS() =", err)
 	}
 	if panicConcurrency != wantPConcurrency {
 		t.Errorf("PanicConcurrency() = %v, want %v", panicConcurrency, wantPConcurrency)
@@ -186,26 +266,26 @@ func TestMetricCollectorScraper(t *testing.T) {
 	mtp.Channel <- now
 
 	// Wait for async loop to finish.
-	wait.PollImmediate(10*time.Millisecond, 100*time.Millisecond, func() (bool, error) {
+	if err := wait.PollImmediate(10*time.Millisecond, 2*time.Second, func() (bool, error) {
 		gotConcurrency, _, _ = coll.StableAndPanicConcurrency(metricKey, now.Add(defaultMetric.Spec.StableWindow).Add(-5*time.Second))
 		gotRPS, _, _ = coll.StableAndPanicRPS(metricKey, now.Add(defaultMetric.Spec.StableWindow).Add(-5*time.Second))
 		return gotConcurrency == reportConcurrency*5 && gotRPS == reportRPS*5, nil
-	})
+	}); err != nil {
+		t.Fatalf("Timed out waiting for the expected values to appear: CC = %v, RPS = %v", gotConcurrency, gotRPS)
+	}
 	if gotConcurrency != reportConcurrency*5 {
-		t.Errorf("StableAndPanicConcurrency() = %v, want %v", gotConcurrency, wantConcurrency)
+		t.Errorf("StableAndPanicConcurrency() = %v, want %v", gotConcurrency, reportConcurrency*5)
 	}
 	if gotRPS != reportRPS*5 {
-		t.Errorf("StableAndPanicRPS() = %v, want %v", gotRPS, wantRPS)
+		t.Errorf("StableAndPanicRPS() = %v, want %v", gotRPS, reportRPS*5)
 	}
 
 	// Deleting the metric should cause a calculation error.
 	coll.Delete(defaultNamespace, defaultName)
-	_, _, err = coll.StableAndPanicConcurrency(metricKey, now)
-	if err != ErrNotCollecting {
+	if _, _, err := coll.StableAndPanicConcurrency(metricKey, now); !errors.Is(err, ErrNotCollecting) {
 		t.Errorf("StableAndPanicConcurrency() = %v, want %v", err, ErrNotCollecting)
 	}
-	_, _, err = coll.StableAndPanicRPS(metricKey, now)
-	if err != ErrNotCollecting {
+	if _, _, err := coll.StableAndPanicRPS(metricKey, now); !errors.Is(err, ErrNotCollecting) {
 		t.Errorf("StableAndPanicRPS() = %v, want %v", err, ErrNotCollecting)
 	}
 }
@@ -217,6 +297,10 @@ func TestMetricCollectorNoScraper(t *testing.T) {
 		Channel: make(chan time.Time),
 	}
 	now := time.Now()
+	fc := fake.Clock{
+		FakeClock: clock.NewFakeClock(now),
+		TP:        mtp,
+	}
 	metricKey := types.NamespacedName{Namespace: defaultNamespace, Name: defaultName}
 	const wantStat = 0.
 	stat := Stat{
@@ -227,23 +311,25 @@ func TestMetricCollectorNoScraper(t *testing.T) {
 	factory := scraperFactory(nil, nil)
 
 	coll := NewMetricCollector(factory, logger)
-	coll.tickProvider = mtp.NewTicker // custom ticker.
+	coll.clock = fc
 
 	noTargetMetric := defaultMetric
 	noTargetMetric.Spec.ScrapeTarget = ""
 	coll.CreateOrUpdate(&noTargetMetric)
 	// Tick three times.  Time doesn't matter since we use the time on the Stat.
-	mtp.Channel <- now
-	mtp.Channel <- now
-	mtp.Channel <- now
+	for i := 0; i < 3; i++ {
+		mtp.Channel <- now
+		now = now.Add(time.Second)
+		fc.SetTime(now)
+	}
 
 	gotConcurrency, panicConcurrency, errCon := coll.StableAndPanicConcurrency(metricKey, now)
 	gotRPS, panicRPS, errRPS := coll.StableAndPanicRPS(metricKey, now)
 	if errCon != nil {
-		t.Errorf("StableAndPanicConcurrency = %v", errCon)
+		t.Error("StableAndPanicConcurrency() =", errCon)
 	}
 	if errRPS != nil {
-		t.Errorf("StableAndPanicRPS = %v", errRPS)
+		t.Error("StableAndPanicRPS() =", errRPS)
 	}
 	if panicConcurrency != wantStat {
 		t.Errorf("PanicConcurrency() = %v, want %v", panicConcurrency, wantStat)
@@ -271,7 +357,7 @@ func TestMetricCollectorNoScraper(t *testing.T) {
 	gotConcurrency, _, _ = coll.StableAndPanicConcurrency(metricKey, now)
 	gotRPS, _, err := coll.StableAndPanicRPS(metricKey, now)
 	if err != nil {
-		t.Errorf("StableAndPanicRPS = %v", err)
+		t.Error("StableAndPanicRPS() =", err)
 	}
 	if gotRPS != wantRC {
 		t.Errorf("StableRPS() = %v, want %v", gotRPS, wantRC)
@@ -304,11 +390,11 @@ func TestMetricCollectorNoDataError(t *testing.T) {
 	// Verify correct error is returned if ScrapeTarget is set
 	_, _, errCon := coll.StableAndPanicConcurrency(metricKey, now)
 	_, _, errRPS := coll.StableAndPanicRPS(metricKey, now)
-	if errCon != ErrNoData {
-		t.Errorf("StableAndPanicConcurrency = %v", errCon)
+	if !errors.Is(errCon, ErrNoData) {
+		t.Error("StableAndPanicConcurrency() =", errCon)
 	}
-	if errRPS != ErrNoData {
-		t.Errorf("StableAndPanicRPS = %v", errRPS)
+	if !errors.Is(errRPS, ErrNoData) {
+		t.Error("StableAndPanicRPS() =", errRPS)
 	}
 }
 
@@ -342,7 +428,11 @@ func TestMetricCollectorRecord(t *testing.T) {
 	mtp := &fake.ManualTickProvider{
 		Channel: make(chan time.Time),
 	}
-	coll.tickProvider = mtp.NewTicker // This will ensure time based scraping won't interfere.
+	fc := fake.Clock{
+		FakeClock: clock.NewFakeClock(now),
+		TP:        mtp,
+	}
+	coll.clock = fc
 
 	// Freshly created collection does not contain any metrics and should return an error.
 	coll.CreateOrUpdate(&defaultMetric)
@@ -445,8 +535,13 @@ func TestMetricCollectorError(t *testing.T) {
 			mtp := &fake.ManualTickProvider{
 				Channel: make(chan time.Time),
 			}
+			now := time.Now()
+			fc := fake.Clock{
+				FakeClock: clock.NewFakeClock(now),
+				TP:        mtp,
+			}
 			coll := NewMetricCollector(factory, logger)
-			coll.tickProvider = mtp.NewTicker
+			coll.clock = fc
 
 			watchCh := make(chan types.NamespacedName)
 			coll.Watch(func(key types.NamespacedName) {
@@ -455,7 +550,7 @@ func TestMetricCollectorError(t *testing.T) {
 
 			// Create a collection and immediately tick.
 			coll.CreateOrUpdate(testMetric)
-			mtp.Channel <- time.Now()
+			mtp.Channel <- now
 
 			// Expect an event to be propagated because we're erroring.
 			key := types.NamespacedName{Namespace: testMetric.Namespace, Name: testMetric.Name}
@@ -465,7 +560,7 @@ func TestMetricCollectorError(t *testing.T) {
 			}
 
 			// Make sure the error is surfaced via 'CreateOrUpdate', which is called in the reconciler.
-			if err := coll.CreateOrUpdate(testMetric); err != test.expectedError {
+			if err := coll.CreateOrUpdate(testMetric); !errors.Is(err, test.expectedError) {
 				t.Fatalf("CreateOrUpdate = %v, want %v", err, test.expectedError)
 			}
 
