@@ -22,15 +22,15 @@ function knative_setup() {
 
 function setup_auto_tls_env_variables() {
   # DNS zone for the testing domain.
-  export DNS_ZONE="knative-e2e"
+  export AUTO_TLS_TEST_DNS_ZONE="knative-e2e"
   # Google Cloud project that hosts the DNS server for the testing domain `kn-e2e.dev`
-  export CLOUD_DNS_PROJECT="knative-e2e-dns"
+  export AUTO_TLS_TEST_CLOUD_DNS_PROJECT="knative-e2e-dns"
   # The service account credential file used to access the DNS server.
-  export CLOUD_DNS_SERVICE_ACCOUNT_KEY_FILE="${GOOGLE_APPLICATION_CREDENTIALS}"
+  export AUTO_TLS_TEST_CLOUD_DNS_SERVICE_ACCOUNT_KEY_FILE="${GOOGLE_APPLICATION_CREDENTIALS}"
 
-  export DOMAIN_NAME="kn-e2e.dev"
+  export AUTO_TLS_TEST_DOMAIN_NAME="kn-e2e.dev"
 
-  export CUSTOM_DOMAIN_SUFFIX="$(($RANDOM % 10000)).${E2E_PROJECT_ID}.${DOMAIN_NAME}"
+  export CUSTOM_DOMAIN_SUFFIX="$(($RANDOM % 10000)).${E2E_PROJECT_ID}.${AUTO_TLS_TEST_DOMAIN_NAME}"
 
   export TLS_TEST_NAMESPACE="tls"
 
@@ -43,7 +43,7 @@ function setup_auto_tls_env_variables() {
     INGRESS_SERVICE="istio-ingressgateway"
   fi
   local IP=$(kubectl get svc -n ${INGRESS_NAMESPACE} ${INGRESS_SERVICE} -o jsonpath="{.status.loadBalancer.ingress[0].ip}")
-  export INGRESS_IP=${IP}
+  export AUTO_TLS_TEST_INGRESS_IP=${IP}
 }
 
 function setup_custom_domain() {
@@ -86,7 +86,7 @@ function setup_http01_auto_tls() {
   # Rely on the built-in naming (for logstream)
   unset TLS_SERVICE_NAME
   # The full host name of the Knative Service. This is used to configure the DNS record.
-  export FULL_HOST_NAME="*.${TLS_TEST_NAMESPACE}.${CUSTOM_DOMAIN_SUFFIX}"
+  export AUTO_TLS_TEST_FULL_HOST_NAME="*.${TLS_TEST_NAMESPACE}.${CUSTOM_DOMAIN_SUFFIX}"
 
   kubectl delete kcert --all -n "${TLS_TEST_NAMESPACE}"
 
@@ -127,7 +127,7 @@ function setup_selfsigned_per_namespace_auto_tls() {
 
   # SERVING_NSCERT_YAML is set in build_knative_from_source function
   # when building knative.
-  echo "Intall namespace cert controller: ${SERVING_NSCERT_YAML}"
+  echo "Install namespace cert controller: ${SERVING_NSCERT_YAML}"
   if [[ -z "${SERVING_NSCERT_YAML}" ]]; then
     echo "Error: variable SERVING_NSCERT_YAML is not set."
     exit 1
@@ -151,20 +151,34 @@ function cleanup_per_selfsigned_namespace_auto_tls() {
 
 function setup_dns_record() {
   go run ./test/e2e/autotls/config/dnssetup/
+  if [ $? -eq 0 ]; then
+    echo "Successfully set up DNS record"
+  else
+    echo "Error setting up DNS record"
+    exit 1
+  fi
 }
 
 function delete_dns_record() {
   go run ./test/e2e/autotls/config/dnscleanup/
+  if [ $? -eq 0 ]; then
+    echo "Successfully tore down DNS record"
+  else
+    echo "Error deleting up DNS record"
+    exit 1
+  fi
 }
 
 # Script entry point.
 
 # Skip installing istio as an add-on
-initialize $@ --skip-istio-addon
+# Temporarily increasing the cluster size for serving tests to rule out
+# resource/eviction as causes of flakiness.
+initialize "$@" --skip-istio-addon --min-nodes=4 --max-nodes=4
 
 header "Enabling high-availability"
 
-scale_controlplane controller autoscaler-hpa webhook
+scale_controlplane "${HA_COMPONENTS[@]}"
 
 # Wait for a new leader Controller to prevent race conditions during service reconciliation
 wait_for_leader_controller || failed=1
@@ -208,4 +222,7 @@ delete_dns_record
 subheader "Cleanup auto tls"
 cleanup_auto_tls_common
 
+# Remove the kail log file if the test flow passes.
+# This is for preventing too many large log files to be uploaded to GCS in CI.
+rm "${KAIL_LOG_FILE}"
 success
